@@ -10,18 +10,22 @@ class LoggerFactory:
         self.console = console
         self.filename = filename
         self.formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+        if filename:
+            self.file_handler = logging.handlers.RotatingFileHandler(self.filename, maxBytes=1000000, backupCount=5)
+            self.file_handler.setFormatter(self.formatter)
+        if console:
+            self.console_handler = logging.StreamHandler()
+            self.console_handler.setFormatter(self.formatter)
 
     def get_logger(self, name):
         logger = logging.getLogger(name)
         logger.setLevel(self.level)
         if self.filename:
-            file_handler = logging.handlers.RotatingFileHandler(self.filename, maxBytes=1000000, backupCount=5)
-            file_handler.setFormatter(self.formatter)
-            logger.addHandler(file_handler)
+            if self.file_handler not in logger.handlers:
+                logger.addHandler(self.file_handler)
         if self.console:
-            console_handler = logging.StreamHandler()
-            console_handler.setFormatter(self.formatter)
-            logger.addHandler(console_handler)
+            if self.console_handler not in logger.handlers:
+                logger.addHandler(self.console_handler)
         return logger
 
 
