@@ -5,8 +5,6 @@ import logger
 import logging
 import traceback
 
-log = logger.get_logger('app')
-
 
 def call(func, kwargs):
     argspec = inspect.getargspec(func)
@@ -28,6 +26,7 @@ def respond(result, message=None, success=True):
 
 
 def run(runner, debug=False, text=False, exit_code_on_error=1):
+    log = logger.get_logger('app')
     try:
         data = runner()
         if text:
@@ -35,7 +34,7 @@ def run(runner, debug=False, text=False, exit_code_on_error=1):
         else:
             respond(data)
     except Exception, e:
-        log.exception('got an exception')
+        log.exception(e)
         respond(e, str(e), success=False)
         exit(exit_code_on_error)
 
